plone.app.event.at.traverser — plone.app.event 1.0dev documentation

### Navigation

- index
- modules |
- next |
- previous |
- plone.app.event 1.0dev documentation »
- plone.app.event API »

# plone.app.event.at.traverser

class `plone.app.event.at.traverser.` `OccurrenceTraverser`(context, request)

  Archetypes image scale traversing support for OccurrenceTraverser. You can access scale names like so: URL/TO/OBJECT/IMAGEFIELD_SCALENAME.

### Navigation

- index
- modules |
- next |
- previous |
- plone.app.event 1.0dev documentation »
- plone.app.event API »